@@ -1,8 +1,8 @@
 <?php
 /**
- * $Horde: mnemo/index.php,v 1.10.10.4 2006/01/01 21:29:05 jan Exp $
+ * $Horde: mnemo/index.php,v 1.10.10.7 2008/01/02 11:32:25 jan Exp $
  *
- * Copyright 2001-2006 Jon Parise <jon@horde.org>
+ * Copyright 2001-2008 The Horde Project (http://www.horde.org/)
  *
  * See the enclosed file LICENSE for license information (ASL). If you
  * did not receive this file, see http://www.horde.org/licenses/asl.php.
@@ -13,8 +13,8 @@
  */
 
 @define('MNEMO_BASE', dirname(__FILE__));
-$mnemo_configured = (@is_readable(MNEMO_BASE . '/config/conf.php') &&
-                     @is_readable(MNEMO_BASE . '/config/prefs.php'));
+$mnemo_configured = (is_readable(MNEMO_BASE . '/config/conf.php') &&
+                     is_readable(MNEMO_BASE . '/config/prefs.php'));
 
 if (!$mnemo_configured) {
     require MNEMO_BASE . '/../lib/Test.php';
