@@ -2,9 +2,9 @@
 /**
  * Mnemo_Driver:: defines an API for implementing storage backends for Mnemo.
  *
- * $Horde: mnemo/lib/Driver.php,v 1.25.2.10 2007/01/02 13:55:11 jan Exp $
+ * $Horde: mnemo/lib/Driver.php,v 1.25.2.12 2008/01/02 11:32:26 jan Exp $
  *
- * Copyright 2001-2007 Horde Project (http://www.horde.org/)
+ * Copyright 2001-2008 The Horde Project (http://www.horde.org/)
  *
  * See the enclosed file LICENSE for license information (ASL). If you
  * did not receive this file, see http://www.horde.org/licenses/asl.php.
@@ -30,6 +30,32 @@ class Mnemo_Driver {
      */
     var $_notepad = '';
 
+    /**
+     * Crypting processor.
+     *
+     * @var Horde_Crypt_pgp
+     */
+    var $_pgp;
+
+    /**
+     * An error message to throw when something is wrong.
+     *
+     * @var string
+     */
+    var $_errormsg;
+
+    /**
+     * Constructor - All real work is done by initialize().
+     */
+    function Mnemo_Driver($errormsg = null)
+    {
+        if (is_null($errormsg)) {
+            $this->_errormsg = _("The Notes backend is not currently available.");
+        } else {
+            $this->_errormsg = $errormsg;
+        }
+    }
+
     /**
      * Lists memos based on the given criteria. All memos will be
      * returned by default.
@@ -50,9 +76,9 @@ class Mnemo_Driver {
      */
     function generateUID()
     {
-        return date('YmdHis') . '.' .
-            substr(base_convert(microtime(), 10, 36), -16) .
-            '@' . $GLOBALS['conf']['server']['name'];
+        return date('YmdHis') . '.'
+            . substr(str_pad(base_convert(microtime(), 10, 36), 16, uniqid(mt_rand()), STR_PAD_LEFT), -16)
+            . '@' . $GLOBALS['conf']['server']['name'];
     }
 
     /**
@@ -64,23 +90,103 @@ class Mnemo_Driver {
     {
         if (!strstr($body, "\n") && String::length($body) <= 64) {
             return trim($body);
-        } else {
-            $lines = explode("\n", $body);
-            if (!is_array($lines)) {
-                return trim(String::substr($body, 0, 64));
-            } else {
-                // Move to a line with more than spaces.
-                $i = 0;
-                while (isset($lines[$i]) && !preg_match('|[^\s]|', $lines[$i])) {
-                    $i++;
-                }
-                if (String::length($lines[$i]) <= 64) {
-                    return trim($lines[$i]);
-                } else {
-                    return trim(String::substr($lines[$i], 0, 64));
-                }
-            }
         }
+
+        $lines = explode("\n", $body);
+        if (!is_array($lines)) {
+            return trim(String::substr($body, 0, 64));
+        }
+
+        // Move to a line with more than spaces.
+        $i = 0;
+        while (isset($lines[$i]) && !preg_match('|[^\s]|', $lines[$i])) {
+            $i++;
+        }
+        if (String::length($lines[$i]) <= 64) {
+            return trim($lines[$i]);
+        } else {
+            return trim(String::substr($lines[$i], 0, 64));
+        }
+    }
+
+    /**
+     * Loads the PGP encryption driver.
+     */
+    function loadPGP()
+    {
+        if (empty($GLOBALS['conf']['utils']['gnupg'])) {
+            $this->_pgp = PEAR::raiseError(_("Encryption support has not been configured, please contact your administrator."));
+            return;
+        }
+        require_once 'Horde/Crypt.php';
+        $this->_pgp = Horde_Crypt::factory('pgp',
+                                           array('program' => $GLOBALS['conf']['utils']['gnupg'],
+                                                 'temp' => Horde::getTempDir()));
+    }
+
+    /**
+     * Encrypts a note.
+     *
+     * @param string $note        The note text.
+     * @param string $passphrase  The passphrase to encrypt the note with.
+     *
+     * @return string|PEAR_Error  The encrypted text or PEAR_Error on failure.
+     */
+    function encrypt($note, $passphrase)
+    {
+        $this->loadPGP();
+        if (is_a($this->_pgp, 'PEAR_Error')) {
+            return $this->_pgp;
+        }
+        return $this->_pgp->encrypt($note, array('type' => 'message', 'symmetric' => true, 'passphrase' => $passphrase));
+    }
+
+    /**
+     * Decrypts a note.
+     *
+     * @param string $note        The encrypted note text.
+     * @param string $passphrase  The passphrase to decrypt the note with.
+     *
+     * @return string|PEAR_Error  The decrypted text or PEAR_Error on failure.
+     */
+    function decrypt($note, $passphrase)
+    {
+        $this->loadPGP();
+        if (is_a($this->_pgp, 'PEAR_Error')) {
+            return $this->_pgp;
+        }
+        return $this->_pgp->decrypt($note, array('type' => 'message', 'passphrase' => $passphrase));
+    }
+
+    /**
+     * Returns an error message if we are not using a secure connection.
+     *
+     * @return PEAR_Error  Returns a PEAR_Error object if there is no secure
+     *                     connection.
+     */
+    function requireSecureConnection()
+    {
+        $this->loadPGP();
+        if (is_a($this->_pgp, 'PEAR_Error')) {
+            return $this->_pgp;
+        }
+        return $this->_pgp->requireSecureConnection();
+    }
+
+    /**
+     * Returns whether note encryption is supported.
+     *
+     * Checks if PGP support could be loaded, if it supports symmetric
+     * encryption, and if we have a secure connection.
+     *
+     * @return boolean  Whether encryption is suppoted.
+     */
+    function encryptionSupported()
+    {
+        $this->loadPGP();
+        return !is_a($this->_pgp, 'PEAR_Error') &&
+            is_callable(array($this->_pgp, 'encryptedSymmetrically')) &&
+            !is_a($this->requireSecureConnection(), 'PEAR_Error');
     }
 
     /**
@@ -98,7 +204,7 @@ class Mnemo_Driver {
      *                              subclass might need.
      *
      * @return mixed    The newly created concrete Mnemo_Driver instance, or
-     *                  false on an error.
+     *                  dummy instance containing an error message.
      */
     function &factory($notepad = '', $driver = null, $params = null)
     {
@@ -116,8 +222,12 @@ class Mnemo_Driver {
         $class = 'Mnemo_Driver_' . $driver;
         if (class_exists($class)) {
             $mnemo = &new $class($notepad, $params);
+            $result = $mnemo->initialize();
+            if (is_a($result, 'PEAR_Error')) {
+                $mnemo = &new Mnemo_Driver(sprintf(_("The Notes backend is not currently available: %s"), $result->getMessage()));
+            }
         } else {
-            $mnemo = false;
+            $mnemo = &new Mnemo_Driver(sprintf(_("Unable to load the definition of %s."), $class));
         }
 
         return $mnemo;
@@ -188,6 +298,8 @@ class Mnemo_Driver {
 
         $vnote->setAttribute('UID', $memo['uid']);
         $vnote->setAttribute('BODY', $memo['body']);
+        $vnote->setAttribute('SUMMARY', $this->getMemoDescription($memo['body']));
+
         if (!empty($memo['category'])) {
             $vnote->setAttribute('CATEGORIES', $memo['category']);
         }
@@ -247,4 +359,14 @@ class Mnemo_Driver {
         return $memo;
     }
 
+    /**
+     * Retrieves notes from the database.
+     *
+     * @return mixed  True on success, PEAR_Error on failure.
+     */
+    function retrieve()
+    {
+        return PEAR::raiseError($this->_errormsg);
+    }
+
 }
