@@ -5,9 +5,9 @@
  * This file defines Mnemo's external API interface.  Other applications can
  * interact with Mnemo through this API.
  *
- * $Horde: mnemo/lib/api.php,v 1.53.2.17 2006/06/26 17:54:16 selsky Exp $
+ * $Horde: mnemo/lib/api.php,v 1.53.2.24 2008/05/12 12:22:38 jan Exp $
  *
- * Copyright 2001-2006 Horde Project (http://www.horde.org/)
+ * Copyright 2001-2008 The Horde Project (http://www.horde.org/)
  *
  * See the enclosed file LICENSE for license information (ASL). If you
  * did not receive this file, see http://www.horde.org/licenses/asl.php.
@@ -21,6 +21,11 @@ $_services['perms'] = array(
     'type' => '{urn:horde}stringArray'
 );
 
+$_services['removeUserData'] = array(
+    'args' => array('user' => 'string'),
+    'type' => 'boolean'
+);
+
 $_services['show'] = array(
     'link' => '%application%/view.php?memolist=|notepad|&memo=|note|&uid=|uid|',
 );
@@ -65,7 +70,11 @@ $_services['replace'] = array(
     'type' => 'boolean'
 );
 
-
+/**
+ * Returns a list of available permissions.
+ *
+ * @return array  An array describing all available permissions.
+ */
 function _mnemo_perms()
 {
     $perms = array();
@@ -76,6 +85,41 @@ function _mnemo_perms()
     return $perms;
 }
 
+/**
+ * Removes user data.
+ *
+ * @param string $user  Name of user to remove data for.
+ *
+ * @return mixed  true on success | PEAR_Error on failure
+ */
+function _mnemo_removeUserData($user)
+{
+    /* Retrieve all entries for user datasource ... */
+    $uids = _mnemo_list($user);
+    if (is_a($uids, 'PEAR_Error')) {
+        return $uids;
+    }
+
+    /* ... and delete them. */
+    foreach ($uids as $uid) {
+        _mnemo_delete($uid);
+    }
+
+    /* Now delete history as well. */
+    $history = &Horde_History::singleton();
+    if (method_exists($history, 'removeByParent')) {
+        $histories = $history->removeByParent('mnemo:' . $user);
+   } else {
+        /* Remove entries 100 at a time. */
+        $all = array_keys($history->getByTimestamp('>', 0, array(), 'mnemo:' . $user));
+        while (count($d = array_splice($all, 0, 100)) > 0) {
+            $history->removebyNames($d);
+        }
+    }
+
+    return true;
+}
+
 /**
  * @param boolean $owneronly   Only return notepads that this user owns?
  *                             Defaults to false.
@@ -83,7 +127,7 @@ function _mnemo_perms()
  *
  * @return array  The notepads.
  */
-function _mnemo_listNotepads($owneronly, $permission)
+function &_mnemo_listNotepads($owneronly, $permission)
 {
     require_once dirname(__FILE__) . '/base.php';
 
@@ -91,8 +135,10 @@ function _mnemo_listNotepads($owneronly, $permission)
 }
 
 /**
- * Returns an array of UIDs for all notes that the current user is
- * authorized to see.
+ * Returns an array of UIDs for all notes that the current user is authorized
+ * to see.
+ *
+ * @param string $notepad  The notepad to list notes from.
  *
  * @return array  An array of UIDs for all notes the user can access.
  */
@@ -101,8 +147,7 @@ function _mnemo_list($notepad = null)
     require_once dirname(__FILE__) . '/base.php';
     global $conf;
 
-    if (!isset($conf['storage']['driver']) ||
-        !isset($conf['storage']['params'])) {
+    if (!isset($conf['storage']['driver'])) {
         return PEAR::raiseError('Not configured');
     }
 
@@ -111,6 +156,11 @@ function _mnemo_list($notepad = null)
         $notepad = Mnemo::getDefaultNotepad();
     }
 
+    if (!array_key_exists($notepad,
+                          Mnemo::listNotepads(false, PERMS_READ))) {
+        return PEAR::raiseError(_("Permission Denied"));
+    }
+
     /* Set notepad for listMemos. */
     $GLOBALS['display_notepads'] = array($notepad);
 
@@ -128,8 +178,8 @@ function _mnemo_list($notepad = null)
 }
 
 /**
- * Returns an array of UIDs for notes that have had $action happen
- * since $timestamp.
+ * Returns an array of UIDs for notes that have had $action happen since
+ * $timestamp.
  *
  * @param string  $action     The action to check for - add, modify, or delete.
  * @param integer $timestamp  The time to start the search.
@@ -146,6 +196,11 @@ function _mnemo_listBy($action, $timestamp, $notepad = null)
         $notepad = Mnemo::getDefaultNotepad();
     }
 
+    if (!array_key_exists($notepad,
+                          Mnemo::listNotepads(false, PERMS_READ))) {
+        return PEAR::raiseError(_("Permission Denied"));
+    }
+
     $history = &Horde_History::singleton();
     $histories = $history->getByTimestamp('>', $timestamp, array(array('op' => '=', 'field' => 'action', 'value' => $action)), 'mnemo:' . $notepad);
     if (is_a($histories, 'PEAR_Error')) {
@@ -174,6 +229,11 @@ function _mnemo_getActionTimestamp($uid, $action, $notepad = null)
         $notepad = Mnemo::getDefaultNotepad();
     }
 
+    if (!array_key_exists($notepad,
+                          Mnemo::listNotepads(false, PERMS_READ))) {
+        return PEAR::raiseError(_("Permission Denied"));
+    }
+
     $history = &Horde_History::singleton();
     return $history->getActionTimestamp('mnemo:' . $notepad . ':' . $uid, $action);
 }
@@ -205,7 +265,6 @@ function _mnemo_import($content, $contentType, $notepad = null)
     }
 
     /* Create a Mnemo_Driver instance. */
-    require_once MNEMO_BASE . '/lib/Driver.php';
     $storage = &Mnemo_Driver::singleton($notepad);
 
     switch ($contentType) {
@@ -288,10 +347,19 @@ function _mnemo_export($uid, $contentType)
         return $memo;
     }
 
-    if (!array_key_exists($memo['memolist_id'], Mnemo::listNotepads(false, PERMS_EDIT))) {
+    if (!array_key_exists($memo['memolist_id'], Mnemo::listNotepads(false, PERMS_READ))) {
         return PEAR::raiseError(_("Permission Denied"));
     }
 
+    if (is_a($memo['body'], 'PEAR_Error')) {
+        if ($memo['body']->getCode() == MNEMO_ERR_NO_PASSPHRASE ||
+            $memo['body']->getCode() == MNEMO_ERR_DECRYPT) {
+            $memo['body'] = _("This note has been encrypted.");
+        } else {
+            return $memo['body'];
+        }
+    }
+
     switch ($contentType) {
     case 'text/plain':
         return $memo['body'];
@@ -345,7 +413,9 @@ function _mnemo_delete($uid)
         return $memo;
     }
 
-    if (!array_key_exists($memo['memolist_id'], Mnemo::listNotepads(false, PERMS_DELETE))) {
+    if (!Auth::isAdmin() &&
+        !array_key_exists($memo['memolist_id'],
+                          Mnemo::listNotepads(false, PERMS_DELETE))) {
         return PEAR::raiseError(_("Permission Denied"));
     }
 
