@@ -1,8 +1,8 @@
 <?php
 /**
- * $Horde: mnemo/lib/prefs.php,v 1.2.10.5 2006/07/17 10:33:08 jan Exp $
+ * $Horde: mnemo/lib/prefs.php,v 1.2.10.8 2008/01/02 11:32:27 jan Exp $
  *
- * Copyright 2002-2006 Chuck Hagenbuch <chuck@horde.org>
+ * Copyright 2002-2008 The Horde Project (http://www.horde.org/)
  *
  * See the enclosed file LICENSE for license information (ASL). If you
  * did not receive this file, see http://www.horde.org/licenses/asl.php.
@@ -18,7 +18,7 @@ function handle_notepadselect($updated)
 
     $default_notepad = Util::getFormData('default_notepad');
     if (!is_null($default_notepad)) {
-        $notepads = Mnemo::listNotepads();
+        $notepads = &Mnemo::listNotepads();
         if (is_array($notepads) && array_key_exists($default_notepad, $notepads)) {
             $prefs->setValue('default_notepad', $default_notepad);
             $updated = true;
